"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _lodash = _interopRequireDefault(require("lodash.get"));

var _WrappedComponent = _interopRequireDefault(require("./WrappedComponent"));

var _space2 = require("../utils/space");

var _align2 = require("../utils/box/align");

var _border2 = require("../utils/border");

var _size2 = require("../utils/box/size");

var _flex2 = require("../utils/box/flex");

var _rows = require("../utils/box/rows");

var _radius2 = require("../utils/box/radius");

var _shadow2 = require("../utils/box/shadow");

var _opacity2 = require("../utils/opacity");

var _flattenStyle = require("../utils/flattenStyle");

var _position2 = require("../utils/position");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const Box = ({
  theme,
  m,
  margin,
  mb,
  marginBottom,
  mt,
  marginTop,
  mr,
  marginRight,
  ml,
  marginLeft,
  my,
  marginVertical,
  mx,
  marginHorizontal,
  p,
  padding,
  pb,
  paddingBottom,
  py,
  paddingVertical,
  pt,
  paddingTop,
  pr,
  paddingRight,
  pl,
  paddingLeft,
  px,
  paddingHorizontal,
  radius,
  borderRadius,
  avatar,
  circle,
  center,
  border,
  shadow,
  boxShadow,
  f,
  flex,
  h,
  height,
  w,
  width,
  align,
  alignItems,
  justify,
  justifyContent,
  self,
  alignSelf,
  dir,
  flexDirection,
  flexWrap,
  o,
  opacity,
  bg,
  backgroundColor,
  rows,
  children,
  position,
  top,
  bottom,
  left,
  right,
  style: customStyle,
  ...rest
}) => {
  const _space = (0, _space2.spaceUtils)({
    m: m !== null && m !== void 0 ? m : margin,
    mb: mb !== null && mb !== void 0 ? mb : marginBottom,
    mt: mt !== null && mt !== void 0 ? mt : marginTop,
    mr: mr !== null && mr !== void 0 ? mr : marginRight,
    ml: ml !== null && ml !== void 0 ? ml : marginLeft,
    my: my !== null && my !== void 0 ? my : marginVertical,
    mx: mx !== null && mx !== void 0 ? mx : marginHorizontal,
    p: p !== null && p !== void 0 ? p : padding,
    pb: pb !== null && pb !== void 0 ? pb : paddingBottom,
    py: py !== null && py !== void 0 ? py : paddingVertical,
    pt: pt !== null && pt !== void 0 ? pt : paddingTop,
    pr: pr !== null && pr !== void 0 ? pr : paddingRight,
    pl: pl !== null && pl !== void 0 ? pl : paddingLeft,
    px: px !== null && px !== void 0 ? px : paddingHorizontal,
    theme
  });

  const _align = (0, _align2.boxAlignUtils)({
    center
  });

  const _border = (0, _border2.borderUtils)({
    border,
    theme
  });

  const _shadow = (0, _shadow2.shadowUtils)({
    shadow: shadow !== null && shadow !== void 0 ? shadow : boxShadow,
    theme
  });

  const _size = (0, _size2.boxSizeUtils)({
    w: w !== null && w !== void 0 ? w : width,
    h: h !== null && h !== void 0 ? h : height
  });

  const _flex = (0, _flex2.boxFlexUtils)({
    align: align !== null && align !== void 0 ? align : alignItems,
    justify: justify !== null && justify !== void 0 ? justify : justifyContent,
    dir: dir !== null && dir !== void 0 ? dir : flexDirection,
    f: f !== null && f !== void 0 ? f : flex,
    self: self !== null && self !== void 0 ? self : alignSelf,
    flexWrap
  });

  const _radius = (0, _radius2.radiusUtils)({
    theme,
    radius: radius !== null && radius !== void 0 ? radius : borderRadius,
    circle,
    avatar,
    children,
    size: {
      height: h !== null && h !== void 0 ? h : height,
      width: w !== null && w !== void 0 ? w : width
    }
  });

  const _opacity = (0, _opacity2.opacityUtils)({
    o: o !== null && o !== void 0 ? o : opacity,
    theme
  });

  const _position = (0, _position2.positionUtils)({
    position,
    top,
    bottom,
    right,
    left
  });

  const _style = {};
  const themeColor = (0, _lodash.default)(theme, 'color');

  const _bg = bg !== null && bg !== void 0 ? bg : backgroundColor;

  if (_bg) {
    const color = themeColor[_bg];

    if (color) {
      _style.backgroundColor = color;
    } else {
      _style.backgroundColor = _bg;
    }
  }

  let newChild;

  if (avatar) {
    newChild = _radius.children;
  } else {
    newChild = (0, _rows.boxRowsUtils)({
      rows,
      children
    });
  }

  const _customStyle = (0, _flattenStyle.flattenStyle)(customStyle);

  const style = _reactNative.StyleSheet.create({
    box: { ..._style,
      ..._space,
      ..._align,
      ..._border,
      ..._shadow,
      ..._size,
      ..._flex,
      ..._radius.style,
      ..._opacity,
      ..._position,
      ..._customStyle
    }
  });

  return /*#__PURE__*/React.createElement(_reactNative.View, _extends({}, rest, {
    style: style.box
  }), newChild);
};

Box.defaultProps = {
  style: {}
};
Box.displayName = 'Box';

var _default = (0, _WrappedComponent.default)(Box);

exports.default = _default;
//# sourceMappingURL=Box.js.map