"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.manipulationUtils = void 0;

var _lodash = _interopRequireDefault(require("lodash.get"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const capitalizeText = str => str.charAt(0).toUpperCase() + str.slice(1);

const capitalizeEachWords = str => str.split(' ').map(capitalizeText).join(' ').trim();

const thousandSeparator = str => String(str).replace(/\B(?=(\d{3})+(?!\d))/g, ',');

const manipulationUtils = props => {
  let newChild = props.children;

  if (typeof props.children === 'string') {
    const uppercase = (0, _lodash.default)(props, 'uppercase');
    const lowercase = (0, _lodash.default)(props, 'lowercase');
    const capitalize = (0, _lodash.default)(props, 'capitalize');
    const capitalizeEach = (0, _lodash.default)(props, 'capitalizeEach');
    const thousand = (0, _lodash.default)(props, 'thousand');

    if (uppercase) {
      newChild = props.children.toUpperCase();
    }

    if (lowercase) {
      newChild = props.children.toLowerCase();
    }

    if (capitalize) {
      newChild = capitalizeText(props.children);
    }

    if (capitalizeEach) {
      newChild = capitalizeEachWords(props.children);
    }

    if (thousand) {
      newChild = thousandSeparator(props.children);
    }
  }

  return newChild;
};

exports.manipulationUtils = manipulationUtils;
//# sourceMappingURL=manipulation.js.map